/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: 8060_CMPVIE_PREVCONGER.SQL

Descrio:
Agrupa a previso de consumo do planejamento alimentao industrial (PREVCONS)
e dos sistemas de comissaria (PREVCOMPRA), levando em consideracao as previsoes
de consumo e solicitacoes das Filiais para Necessidade de Compras.

Para aplicar
H:\SISTEMAS\DBA\SQL\SQLSER\8060_CMPVIE_PREVCONGER.SQL

Criao:
23/02/99 - Yoris L. de Souza
*/

IF EXISTS (SELECT * FROM sysobjects O, sysusers U
          WHERE
            o.name = 'PREVCONGER'  and
            Xtype = 'V'                  and
            u.uid = o.uid               and
            u.name = USER)
  DROP VIEW PREVCONGER;
GO

CREATE VIEW PREVCONGER AS
SELECT
   A.CDFILIAL,
   A.DTPREVCONS,
   A.CDPRODUTO,
   SUM(A.QTPRODCONS) AS QTPRODCONS
FROM
   (SELECT
       CDFILIAL,
       DTPREVCONS AS DTPREVCONS,
       CDPRODUTO,
       QTPREVCONS AS QTPRODCONS
    FROM
       PREVCONS
    UNION ALL
    SELECT
       CDFILIAL,
       DTPREVCOMP AS DTPREVCONS,
       CDPRODUTO,
       QTPRODCOMP AS QTPRODCONS
    FROM
       PREVCOMPRA
    UNION ALL
    SELECT
       PC.CDFILIAL,
       CONVERT(DATETIME, CONVERT(VARCHAR, PV.DTPREVCONPDV, 103)) AS DTPREVCONS,
       PC.CDPRODUTO,
       SUM(PC.QTPRODCONPDV) AS QTPRODCONS
    FROM
       PREVCONSPDV PC,
       PREVISAOPDV PV
    WHERE
    	 (PC.CDFILIAL = PV.CDFILIAL) AND
       (PC.NRSEQPREVPDV = PV.NRSEQPREVPDV) AND
       (PC.CDPRODUTO <> PC.CDPRPAIPCPDV)
    GROUP BY
    	 PC.CDFILIAL,
       CONVERT(DATETIME, CONVERT(VARCHAR, PV.DTPREVCONPDV, 103)),
       PC.CDPRODUTO

    UNION ALL
    SELECT
       CDFILIALCLIE,
       CONVERT(DATETIME, CONVERT(VARCHAR, DTPREVENDVMN, 103)) AS DTPREVCONS,
       CDPRODUTO,
       QTSOLCONVMN AS QTPRODCONS
    FROM PREVCONSVMN
    UNION ALL
    SELECT
       FI.CDFILIAL,
       PC.DTPREVCONS AS DTPREVCONS,
       PC.CDPRODUTO,
       PC.QTPREVCONS AS QTPRODCONS
    FROM
       PRODUTO PROD_PREV,
       PREVCONS PC,
       FILINECE FI
    WHERE
       (FI.CDFILINECCMP = PC.CDFILIAL)         AND
       (FI.IDSOLIPREV   = 'P')                 AND
       (PC.CDPRODUTO    = PROD_PREV.CDPRODUTO) AND
       (NOT EXISTS(SELECT P.CDARVPROD
                   FROM PRODCMPFILI, PRODUTO P
                   WHERE
                      PRODCMPFILI.CDPRODUTO = P.CDPRODUTO     AND
                      PRODCMPFILI.CDFILIAL  = FI.CDFILINECCMP AND
                      PROD_PREV.CDARVPROD LIKE P.CDARVPROD+'%' AND
                      P.CDARVPROD > (SELECT ISNULL(MAX(PR.CDARVPROD), 0)
                                     FROM PRODNCMP, PRODUTO PR
                                     WHERE PRODNCMP.CDPRODUTO = PR.CDPRODUTO AND
                                           PROD_PREV.CDARVPROD LIKE PR.CDARVPROD+'%' AND
                                           PRODNCMP.CDFILIAL = FI.CDFILINECCMP)))

    UNION ALL
    SELECT
       FI.CDFILIAL,
       PC.DTPREVCOMP AS DTPREVCONS,
       PC.CDPRODUTO,
       PC.QTPRODCOMP AS QTPRODCONS
    FROM
       PRODUTO PROD_PREV,
       PREVCOMPRA PC,
       FILINECE FI
    WHERE
       (FI.CDFILINECCMP = PC.CDFILIAL)         AND
       (FI.IDSOLIPREV   = 'P')                 AND
       (PC.CDPRODUTO    = PROD_PREV.CDPRODUTO) AND
       (NOT EXISTS(SELECT P.CDARVPROD
                   FROM PRODCMPFILI, PRODUTO P
                   WHERE
                      PRODCMPFILI.CDPRODUTO = P.CDPRODUTO     AND
                      PRODCMPFILI.CDFILIAL  = FI.CDFILINECCMP AND
                      PROD_PREV.CDARVPROD LIKE P.CDARVPROD+'%' AND
                      P.CDARVPROD > (SELECT ISNULL(MAX(PR.CDARVPROD), 0)
                                     FROM PRODNCMP, PRODUTO PR
                                     WHERE PRODNCMP.CDPRODUTO = PR.CDPRODUTO AND
                                           PROD_PREV.CDARVPROD LIKE PR.CDARVPROD+'%' AND
                                           PRODNCMP.CDFILIAL = FI.CDFILINECCMP)))


    UNION ALL
    SELECT
       FI.CDFILIAL,
       CONVERT(DATETIME, CONVERT(VARCHAR, PV.DTPREVCONPDV, 103)) AS DTPREVCONS,
       PC.CDPRODUTO,
       SUM(PC.QTPRODCONPDV) AS QTPRODCONS
    FROM
       PREVCONSPDV PC,
       PREVISAOPDV PV,
       PRODUTO PROD_PREV,
       FILINECE FI
    WHERE
    	 (PC.CDFILIAL = PV.CDFILIAL) AND
       (PC.NRSEQPREVPDV = PV.NRSEQPREVPDV) AND
       (PC.CDPRODUTO <> PC.CDPRPAIPCPDV) AND
       (FI.CDFILINECCMP = PC.CDFILIAL) AND
       (FI.IDSOLIPREV   = 'P')         AND
       (PROD_PREV.CDPRODUTO = PC.CDPRODUTO) AND
       (NOT EXISTS(SELECT P.CDARVPROD
            FROM PRODCMPFILI, PRODUTO P
            WHERE
               PRODCMPFILI.CDPRODUTO = P.CDPRODUTO     AND
               PRODCMPFILI.CDFILIAL  = FI.CDFILINECCMP AND
               PROD_PREV.CDARVPROD LIKE P.CDARVPROD+'%' AND
               P.CDARVPROD > (SELECT ISNULL(MAX(PR.CDARVPROD), 0)
                              FROM PRODNCMP, PRODUTO PR
                              WHERE PRODNCMP.CDPRODUTO = PR.CDPRODUTO AND
                                    PROD_PREV.CDARVPROD LIKE PR.CDARVPROD+'%' AND
                                    PRODNCMP.CDFILIAL = FI.CDFILINECCMP)))

    GROUP BY
    	 FI.CDFILIAL,
       CONVERT(DATETIME, CONVERT(VARCHAR, PV.DTPREVCONPDV, 103)),
       PC.CDPRODUTO

    UNION ALL
    SELECT
       FI.CDFILIAL,
       CONVERT(DATETIME, CONVERT(VARCHAR, PC.DTPREVENDVMN, 103)) AS DTPREVCONS,
       PC.CDPRODUTO,
       PC.QTSOLCONVMN AS QTPRODCONS
    FROM
       PREVCONSVMN PC,
       PRODUTO PROD_PREV,
       FILINECE FI
    WHERE
       (FI.CDFILINECCMP = PC.CDFILIALCLIE)  AND
       (FI.IDSOLIPREV   = 'P')              AND
       (PROD_PREV.CDPRODUTO = PC.CDPRODUTO) AND
       (NOT EXISTS(SELECT P.CDARVPROD
                   FROM PRODCMPFILI, PRODUTO P
                   WHERE
                      PRODCMPFILI.CDPRODUTO = P.CDPRODUTO     AND
                      PRODCMPFILI.CDFILIAL  = FI.CDFILINECCMP AND
                      PROD_PREV.CDARVPROD LIKE P.CDARVPROD+'%' AND
                      P.CDARVPROD > (SELECT ISNULL(MAX(PR.CDARVPROD), 0)
                                     FROM PRODNCMP, PRODUTO PR
                                     WHERE PRODNCMP.CDPRODUTO = PR.CDPRODUTO AND
                                           PROD_PREV.CDARVPROD LIKE PR.CDARVPROD+'%' AND
                                           PRODNCMP.CDFILIAL = FI.CDFILINECCMP)))

    UNION ALL
    SELECT
       FI.CDFILIAL,
       IT.DTPROGENTR                 AS DTPREVCONS,
       PR.CDPRODESTO                 AS CDPRODUTO,
       IT.QTSOLIPROD * PR.VRFATOCONV AS QTPRODCONS
    FROM
       ITEMSOLI IT,
       PRODUTO PR,
       FILINECE FI
    WHERE
       (FI.CDFILINECCMP = IT.CDFILSOLI) AND
       (FI.IDSOLIPREV  <> 'P')          AND
       (IT.CDPRODUTO    = PR.CDPRODUTO) AND
       (NOT EXISTS(SELECT P.CDARVPROD
                   FROM PRODCMPFILI, PRODUTO P
                   WHERE
                      PRODCMPFILI.CDPRODUTO = P.CDPRODUTO     AND
                      PRODCMPFILI.CDFILIAL  = FI.CDFILINECCMP AND
                      PR.CDARVPROD LIKE P.CDARVPROD+'%' AND
                      P.CDARVPROD > (SELECT ISNULL(MAX(PR.CDARVPROD), 0)
                                     FROM PRODNCMP, PRODUTO PR
                                     WHERE PRODNCMP.CDPRODUTO = PR.CDPRODUTO AND
                                           PR.CDARVPROD LIKE PR.CDARVPROD+'%' AND
                                           PRODNCMP.CDFILIAL = FI.CDFILINECCMP)))) A
GROUP BY
   A.CDFILIAL,
   A.DTPREVCONS,
   A.CDPRODUTO

GO